Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(419)

Unified Diff: ios/web/navigation/crw_session_controller+private_constructors.h

Issue 2766063002: Remove the concept of currentItemIndex (Closed)
Patch Set: fix unit tests Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/web/navigation/crw_session_controller.mm ('k') | ios/web/navigation/crw_session_controller_unittest.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web/navigation/crw_session_controller+private_constructors.h
diff --git a/ios/web/navigation/crw_session_controller+private_constructors.h b/ios/web/navigation/crw_session_controller+private_constructors.h
index 9afd605ec5bce55dfe6d15aa547e5483cdbb637f..b10295de8da9b122511e2fba4924365e47355d24 100644
--- a/ios/web/navigation/crw_session_controller+private_constructors.h
+++ b/ios/web/navigation/crw_session_controller+private_constructors.h
@@ -24,10 +24,10 @@ class NavigationItem;
- (instancetype)initWithBrowserState:(web::BrowserState*)browserState;
// Initializes a session controller, supplying a list of NavigationItem objects
-// and the current index in the navigation history.
+// and the last committed item index in the navigation history.
- (instancetype)initWithBrowserState:(web::BrowserState*)browserState
navigationItems:(web::ScopedNavigationItemList)items
- currentIndex:(NSUInteger)currentIndex;
+ lastCommittedItemIndex:(NSUInteger)lastCommittedItemIndex;
@end
#endif // IOS_WEB_NAVIGATION_CRW_SESSION_CONTROLLER_PRIVATE_CONSTRUCTORS_H_
« no previous file with comments | « ios/web/navigation/crw_session_controller.mm ('k') | ios/web/navigation/crw_session_controller_unittest.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698